# Models

Typed dataclass responses returned by PyhoodClient methods.

::: pyhood.models.Quote

::: pyhood.models.OptionContract

::: pyhood.models.OptionsChain

::: pyhood.models.Position

::: pyhood.models.Order

::: pyhood.models.Earnings

::: pyhood.models.FuturesContract

::: pyhood.models.FuturesQuote

::: pyhood.models.FuturesOrder

::: pyhood.models.FuturesPnL
